#Conditionally import wlstModule only when script is executed with jython
if __name__ == '__main__': 
    from wlstModule import *#@UnusedWildImport
    


######################################################################################
# ELJMSCacheCoordination - WLST Script For Setting Up The WebLogic Server Domain     #
#                                                                                    #
# Author: Reinhard Girstenbrei, Oracle Corporation                                   #
#                                                                                    #
# Configuration in: weblogic.properties                                              #
#                                                                                    #
######################################################################################



def loadProperties():
    propertiesInputStream = java.io.FileInputStream("weblogic.properties")
    properties = java.util.Properties()      
    properties.load(propertiesInputStream)
    propertiesInputStream = java.io.FileInputStream("project.properties")
    properties.load(propertiesInputStream)
    return properties

def configureMachine(machineName, listenAddress, listenPort):
    try:
        print "Creating Machine \"" + machineName + "\""
        cd('/')
        cmo.createMachine(machineName)
        cd('/Machines/' + machineName + '/NodeManager/' + machineName)
        cmo.setNMType('SSL')
        cmo.setListenAddress(listenAddress)
        cmo.setListenPort(int(listenPort))
        cmo.setDebugEnabled(false)
    except Exception, e:
        print "Error: Machine \"" + machineName + "\" does already exist"
    print ""


def configureManagedServer(serverName, listenAddress, listenPort, machineName):
    try:
        print "Creating Managed Server \"" + serverName + "\"" 
        cd('/')
        cmo.createServer(serverName)
        cd('/Servers/' + serverName)
        cmo.setListenAddress(listenAddress)
        cmo.setListenPort(int(listenPort))
        cmo.setListenPortEnabled(true)
        cmo.setJavaCompiler('javac')
        cmo.setClientCertProxyEnabled(false)
        cmo.setMachine(getMBean('/Machines/' + machineName))
        cd('/Servers/' + serverName +'/SSL/' + serverName)
        cmo.setEnabled(false)
        cd('/Servers/'+ serverName + '/ServerDiagnosticConfig/' + serverName)
        cmo.setWLDFDiagnosticVolume('Low')
    except Exception, e:
        print "Error: Managed Server \"" + serverName + "\" does already exist"
    print ""
        
        
def configureGridLinkDatasource (datasourceClassName, datasourceName, datasourceJNDI, username, password, url, managedServerName, isGlobalTx):
    try:
        print "Creating GridLink DataSource \"" + datasourceName + "\""
        cd('/')
        cmo.createJDBCSystemResource(datasourceName)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName)
        cmo.setName(datasourceName)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDataSourceParams/' + datasourceName)
        set('JNDINames',jarray.array([String(datasourceJNDI)], String))
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName)
        cmo.setUrl(url)
        cmo.setDriverName(datasourceClassName)
        cmo.setPassword(password)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCConnectionPoolParams/' + datasourceName)
        cmo.setTestTableName('SQL SELECT 1 FROM DUAL\r\n')
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName + '/Properties/' + datasourceName)
        cmo.createProperty('user')
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDriverParams/' + datasourceName + '/Properties/' + datasourceName + '/Properties/user')
        cmo.setValue(username)
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCDataSourceParams/' + datasourceName)
        if isGlobalTx == True:
            cmo.setGlobalTransactionsProtocol('EmulateTwoPhaseCommit')
        else:
            cmo.setGlobalTransactionsProtocol('TwoPhaseCommit')
    
        cd('/JDBCSystemResources/' + datasourceName + '/JDBCResource/' + datasourceName + '/JDBCOracleParams/' + datasourceName)
        cmo.setFanEnabled(false)
        cmo.setOnsWalletFile('')
        cmo.unSet('OnsWalletPasswordEncrypted')
        cmo.setOnsNodeList('')
        cmo.setFanEnabled(false)
        cmo.setOnsWalletFile('')
        cmo.unSet('OnsWalletPasswordEncrypted')
        cmo.setOnsNodeList('')
        
        cd('/SystemResources/' + datasourceName)
        set('Targets',jarray.array([ObjectName('com.bea:Name=' + managedServerName + ',Type=Server')], ObjectName))

    except Exception, e:
        print "Error: GridLink Datasource \"" + datasourceName + "\" does already exist"
	print ""
    
        

def startupManagedServer(managedServerName):
	try:    
		print "Starting up \"" + managedServerName + "\""
		cd('/')
		start(managedServerName, 'Server',block='false')
	except Exception, e:
		print "Error: Starting up \"" + managedServerName + "\" failed"
	print ""
	
# =========== Main ===============
redirect(System.getProperty('user.dir') + '/setup_wlst.log')
print "*************************************************************"
print "*** Creating a Cluster With Two Nodes On The Same Machine ***"
print "*************************************************************"
print

properties = loadProperties()

# Connect - interactive

#connect()

# Connect - hard coded

connect(
   properties.get('weblogic.admin.username'), 
   properties.get('weblogic.admin.password'), 
   properties.get('weblogic.admin.url'))

edit()
startEdit()
   
configureMachine(
   properties.get('weblogic.machine'),
   properties.get('weblogic.machine.listen.address'),
   properties.get('weblogic.machine.listen.port'))
   
   
configureManagedServer(
   properties.get('weblogic.managed.server1'),
   properties.get('weblogic.managed.server1.listen.address'),
   properties.get('weblogic.managed.server1.listen.port'),
   properties.get('weblogic.machine'))


print ""   
save()
activate(block="true")

edit()
startEdit()

configureGridLinkDatasource(
   properties.get('weblogic.datasource.classname'),
   properties.get('weblogic.datasource'),
   properties.get('weblogic.datasource.jndi'),
   'webuser',
   'webuser',
   properties.get('database.url'),
   properties.get('weblogic.managed.server1'),
   True)

configureGridLinkDatasource(
   properties.get('database.jdbc.driver'),
   properties.get('weblogic.datasource.nonjta'),
   properties.get('weblogic.datasource.jndi.nonjta'),
   'webuser',
   'webuser',
   properties.get('database.url'),
   properties.get('weblogic.managed.server1'),
   False)

print ""   
save()
activate(block="true")

startupManagedServer(
   properties.get('weblogic.managed.server1'))

stopRedirect()
disconnect()
print""
print "*************************************************************"
print "Script finished."
print "*************************************************************"
