package oracle.support.model;

import java.util.HashMap;
import java.util.Map;
import javax.ejb.Local;
import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceUnit;

import oracle.jdbc.OracleConnection;
import oracle.support.security.UserToken;

import org.eclipse.persistence.config.EntityManagerProperties;
import org.eclipse.persistence.internal.security.JCEEncryptor;
import org.eclipse.persistence.sessions.JNDIConnector;


/**
 * Session Bean implementation class TestFacade
 */
@Stateless(name = "TestFacade", mappedName = "TestFacade")
@Local(TestFacadeLocal.class)
public class TestFacade implements TestFacadeLocal {
	// @PersistenceContext(unitName = "pu")
	// private EntityManager em;
	@PersistenceUnit(unitName = "pu")
	EntityManagerFactory emf;
	private JCEEncryptor encryptor = null;

	public TestFacade() throws Exception {
		encryptor = new JCEEncryptor();
	}

	// Workaround: Always use a transaction.
	// If there is no transaction then the proxy session will not be created
	// with the supplied proxy session credentials.
	// @TransactionAttribute(TransactionAttributeType.SUPPORTS)
	public String readValue(UserToken userToken) {
		Map emProperties = new HashMap();
		emProperties.put("eclipselink.oracle.proxy-type",
				OracleConnection.PROXYTYPE_USER_NAME);
		emProperties.put(OracleConnection.PROXY_USER_NAME,
				userToken.getUsername());
		emProperties.put(OracleConnection.PROXY_USER_PASSWORD,
				this.decrypt(userToken.getPassword()));
		EntityManager em = emf.createEntityManager(emProperties);
		// ((org.eclipse.persistence.internal.jpa.EntityManagerImpl)em.getDelegate()).setProperties(emProperties);
		System.out
				.println(((org.eclipse.persistence.internal.jpa.EntityManagerImpl) em
						.getDelegate()).getProperties());
		TestEntity testEntity = (TestEntity) em.find(TestEntity.class, 1L);
		StringBuffer buffer = new StringBuffer();
		buffer.append("test: id=" + testEntity.getId());
		buffer.append(", value=" + testEntity.getValue());
		buffer.append("\n");
		String s = buffer.toString();
		System.out.println(s);
		return s;
	}

	public String incrementAndReadValue(UserToken userToken) {
		Map emProperties = new HashMap();
		emProperties.put("eclipselink.oracle.proxy-type",
				OracleConnection.PROXYTYPE_USER_NAME);
		emProperties.put(OracleConnection.PROXY_USER_NAME,
				userToken.getUsername());
		emProperties.put(OracleConnection.PROXY_USER_PASSWORD,
				this.decrypt(userToken.getPassword()));
		EntityManager em = emf.createEntityManager(emProperties);
		// ((org.eclipse.persistence.internal.jpa.EntityManagerImpl)em.getDelegate()).setProperties(emProperties);
		System.out
				.println(((org.eclipse.persistence.internal.jpa.EntityManagerImpl) em
						.getDelegate()).getProperties());
		TestEntity testEntity = (TestEntity) em.find(TestEntity.class, 1L);
		testEntity.setValue(testEntity.getValue() + 1);
		StringBuffer buffer = new StringBuffer();
		buffer.append("test: id=" + testEntity.getId());
		buffer.append(", value=" + testEntity.getValue());
		buffer.append("\n");
		String s = buffer.toString();
		System.out.println(s);
		return s;
	}

	@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
	public void authenticate(UserToken userToken) {
		Map emProperties = new HashMap();
		emProperties.put("eclipselink.oracle.proxy-type",
				OracleConnection.PROXYTYPE_USER_NAME);
		emProperties.put(OracleConnection.PROXY_USER_NAME,
				userToken.getUsername());
		emProperties.put(OracleConnection.PROXY_USER_PASSWORD,
				this.decrypt(userToken.getPassword()));
		EntityManager em = emf.createEntityManager(emProperties);
		// ((org.eclipse.persistence.internal.jpa.EntityManagerImpl)em.getDelegate()).setProperties(emProperties);
		System.out
				.println(((org.eclipse.persistence.internal.jpa.EntityManagerImpl) em
						.getDelegate()).getProperties());
		Object object = em.createNativeQuery("select user from dual")
				.getSingleResult();
		System.out.println("Authentication Session Username: " + object);
	}

	public String encrypt(String expression) {
		return encryptor.encryptPassword(expression);
	}

	public String decrypt(String expression) {
		return encryptor.decryptPassword(expression);
	}

}
