package oracle.support.web;

import java.io.IOException;

import javax.ejb.EJB;
import javax.servlet.RequestDispatcher;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import oracle.support.model.TestFacadeLocal;
import oracle.support.security.UserToken;

/**
 * Servlet implementation class ControllerServlet
 */

public class ControllerServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;
	@EJB(name = "MyTestFacade", beanInterface = TestFacadeLocal.class)
	private TestFacadeLocal testFacade;

	/**
	 * @see HttpServlet#HttpServlet()
	 */
	public ControllerServlet() {
		super();
	}

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse
	 *      response)
	 */
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		doPost(request, response);
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse
	 *      response)
	 */
	protected void doPost(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {
		String action = request.getServletPath();
		RequestDispatcher rd = null;
		int dotPosition = action.lastIndexOf(".");
		if (dotPosition != -1) {
			action = action.substring(1, dotPosition);
		}
		if (action.equals("login")) {

			String username = request.getParameter("username");
			String password = request.getParameter("password");
			if (username == null) {
				rd = request.getRequestDispatcher("WEB-INF/jsp/login.jsp");
			} else {
				UserToken userToken = new UserToken(username,
						testFacade.encrypt(password));
				try {
					testFacade.authenticate(userToken);
					rd = request.getRequestDispatcher("WEB-INF/jsp/main.jsp");
					request.getSession().setAttribute("userToken", userToken);
				} catch (Exception ex) {
					request.setAttribute("error", "Authentication failed");
					rd = request.getRequestDispatcher("WEB-INF/jsp/login.jsp");

				}
			}
		} else if (action.equals("logout")) {
			request.getSession().invalidate();
			rd = request.getRequestDispatcher("WEB-INF/jsp/login.jsp");
		} else if (action.equals("write")) {
			rd = request.getRequestDispatcher("WEB-INF/jsp/write.jsp");
		} else if (action.equals("read")) {
			rd = request.getRequestDispatcher("WEB-INF/jsp/read.jsp");
		} else if (action.equals("main")) {
			rd = request.getRequestDispatcher("WEB-INF/jsp/main.jsp");
		}
		if (rd != null) {
			rd.forward(request, response);
		}
	}

}
